@@ -1,5 +1,5 @@
 package Bio::ToolBox::Data::Stream;
-our $VERSION = '1.41';
+our $VERSION = '1.60';
 
 =head1 NAME
 
@@ -714,6 +714,9 @@ sub new {
 			$self->{extension} .= '.gz';
 		}
 		
+		# rebuild the filename after modifying the extension
+		$self->{filename} = $self->{path} . $self->{basename} . $self->{extension};
+		
 		# add feature
 		$args{feature} ||= $args{features} || undef;
 		$self->feature($args{feature}) unless $self->feature;
