@@ -3,7 +3,7 @@
 # documentation at end of file
 
 use strict;
-use Getopt::Long;
+use Getopt::Long qw(:config no_ignore_case bundling);
 use Pod::Usage;
 use File::Spec;
 use Bio::ToolBox::Data;
@@ -11,6 +11,8 @@ use Bio::ToolBox::db_helper qw(
 	open_db_connection
 	verify_or_request_feature_types
 	check_dataset_for_rpm_support
+	$BAM_ADAPTER
+	$BIG_ADAPTER
 );
 use Bio::ToolBox::utility;
 
@@ -21,7 +23,7 @@ eval {
 	$parallel = 1;
 };
 
-my $VERSION = '1.54';
+my $VERSION = '1.60';
 
 
 print "\n A program to collect data for a list of features\n\n";
@@ -64,39 +66,42 @@ my (
 	$gz,
 	$cpu,
 	$help,
+	$verbose,
 	$print_version,
 ); 
 my @datasets; # an array of names of dataset values to be retrieved
 
 # Command line options
 GetOptions( 
-	'in=s'       => \$infile, # load a pre-existing file
-	'new'        => \$new, # generate a new file
-	'out=s'      => \$outfile, # name of new output file 
-	'db=s'       => \$main_database, # main or annotation database name
-	'ddb=s'      => \$data_database, # data database
-	'feature=s'  => \$feature, # name of genomic feature to analyze
-	'method=s'   => \$method, # method of collecting & reporting data
-	'data=s'     => \@datasets, # the list of datasets to collect data from
-	'strand=s'   => \$stranded, # indicate strandedness of data
-	'subfeature=s' => \$subfeature, # indicate to restrict to subfeatures
-	'exons!'     => \$exon_subfeature, # old parameter
-	'extend=i'   => \$extend, # extend the size of the genomic feature
-	'start=i'    => \$start_adj, # adjustment to relative position
-	'stop=i'     => \$stop_adj, # adjustment relative position
-	'fstart=f'   => \$fstart, # fractional start position
-	'fstop=f'    => \$fstop, # fractional stop position
-	'limit=i'    => \$limit, # size limit to fractionate a feature
-	'pos=s'      => \$position, # set the relative feature position
-	'fpkm|rpkm=s' => \$fpkm_method, # set the fpkm method  
-	'win=i'      => \$win, # indicate the size of genomic intervals
-	'step=i'     => \$step, # step size for genomic intervals
+	'i|in=s'           => \$infile, # load a pre-existing file
+	'new'              => \$new, # generate a new file
+	'o|out=s'          => \$outfile, # name of new output file 
+	'd|db=s'           => \$main_database, # main or annotation database name
+	'D|ddb=s'          => \$data_database, # data database
+	'f|feature=s'      => \$feature, # name of genomic feature to analyze
+	'm|method=s'       => \$method, # method of collecting & reporting data
+	'a|data=s'         => \@datasets, # the list of datasets to collect data from
+	't|strand=s'       => \$stranded, # indicate strandedness of data
+	'u|subfeature=s'   => \$subfeature, # indicate to restrict to subfeatures
+	'exons!'           => \$exon_subfeature, # old parameter
+	'x|extend=i'       => \$extend, # extend the size of the genomic feature
+	'b|begin|start=i'  => \$start_adj, # adjustment to relative position
+	'e|end|stop=i'     => \$stop_adj, # adjustment relative position
+	'fstart=f'         => \$fstart, # fractional start position
+	'fstop=f'          => \$fstop, # fractional stop position
+	'limit=i'          => \$limit, # size limit to fractionate a feature
+	'p|pos=s'          => \$position, # set the relative feature position
+	'fpkm|rpkm=s'      => \$fpkm_method, # set the fpkm method  
+	'win=i'            => \$win, # indicate the size of genomic intervals
+	'step=i'           => \$step, # step size for genomic intervals
 	'force_strand|set_strand' => \$set_strand, # enforce a specific strand
 				# force_strand is preferred option, but respect the old option
-	'gz!'        => \$gz, # compress output file
-	'cpu=i'      => \$cpu, # number of execution threads
-	'help'       => \$help, # request help
-	'version'    => \$print_version, # print the version
+	'z|gz!'            => \$gz, # compress output file
+	'c|cpu=i'          => \$cpu, # number of execution threads
+	'h|help'           => \$help, # request help
+	'v|version'        => \$print_version, # print the version
+	'bam=s'            => \$BAM_ADAPTER, # explicitly set the bam adapter
+	'big=s'            => \$BIG_ADAPTER, # explicitly set the big adapter
 ) or die " unrecognized option(s)!! please refer to the help documentation\n\n";
 
 # print help if requested
@@ -858,52 +863,58 @@ A program to collect data for a list of features
 
 =head1 SYNOPSIS
 
-get_datasets.pl [--options...] [<filename>]
+get_datasets.pl [--options...] <filename>
 
 get_datasets.pl [--options...] --in <filename> <data1> <data2...>
   
-  Options for existing files:
-  --in <filename>                  (txt bed gff gtf refFlat ucsc)
+  Options for data files:
+  -i --in <filename>                  input file: txt bed gff gtf refFlat ucsc
+  -o --out <filename>                 optional output file, default overwrite 
   
   Options for new files:
-  --db <name | filename>
-  --feature <type | type:source | alias>, ...
-  --win <integer>                                           (500)
-  --step <integer>                                          (win)
+  -d --db <name>                      annotation database: mysql sqlite
+  -f --feature <type>                 one or more feature types from db or gff
+  
+  Options for feature "genome":
+  --win <integer>                     size of windows across genome (500 bp)
+  --step <integer>                    step size of windows across genome 
   
   Options for data collection:
-  --ddb <name | filename>
-  --data <none | file | type>, ...
-  --method [mean|median|stddev|min|max|range|sum|          (mean)
-            count|pcount|ncount]
-  --strand [all|sense|antisense]                            (all)
-  --force_strand
-  --subfeature [exon|cds|5p_utr|3p_utr]
-  --fpkm [region|genome]
+  -D --ddb <name|file>                data or BigWigSet database
+  -a --data <dataset|filename>        data from which to collect: bw bam etc
+  -m --method [mean|median|stddev|    statistical method for collecting data
+            min|max|range|sum|count|   default mean
+            pcount|ncount]
+  -t --strand [all|sense|antisense]   strand of data relative to feature (all)
+  -u --subfeature [exon|cds|          collect over gene subfeatures 
+        5p_utr|3p_utr] 
+  --force_strand                      use the specified strand in input file
+  --fpkm [region|genome]              convert count data to depth normalized
   
   Adjustments to features:
-  --extend <integer>
-  --start=<integer>
-  --stop=<integer>
-  --fstart=<decimal>
-  --fstop=<decimal>
-  --pos [5|m|3]                                             (5)
-  --limit <integer>
+  -s --extend <integer>               extend the feature in both directions
+  -b --begin --start <integer>        adjust relative start coordinate
+  -e --end --stop <integer>           adjust relative stop coordinate
+  -p --pos [5|m|3]                    define the relative position to adjust
+  --fstart=<decimal>                  adjust fractional start
+  --fstop=<decimal>                   adjust fractional stop
+  --limit <integer>                   minimum size to take fractional window
   
   General options:
-  --out <filename>
-  --gz
-  --cpu <integer>                                           (2)
-  --version
-  --help                              show extended documentation
+  -z --gz                             compress output file
+  -c --cpu <integer>                  number of threads, default 4
+  -v --version                        print version and exit
+  -h --help                           show extended documentation
 
 =head1 OPTIONS
 
 The command line flags and descriptions:
 
+=head2 Options for data files
+
 =over 4
 
-=item --in <filename>
+=item --in E<lt>filenameE<gt>
 
 Specify an input file containing either a list of database features or 
 genomic coordinates for which to collect data. Any tab-delimited text 
@@ -913,53 +924,67 @@ UCSC native formats such as gene prediction tables are all supported.
 Gene annotation files will be parsed as sequence features. 
 Files may be gzipped compressed.
 
-=item --out <filename>
+=item --out E<lt>filenameE<gt>
 
 Specify the output file name. Required for new feature tables; optional for 
 current files. If this is argument is not specified then the input file is 
 overwritten.
 
-=item --db <name | filename>
+=back
+
+=head2 Options for new files
+
+=over 4
+
+=item --db E<lt>name | filenameE<gt>
 
 Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
 from which gene or feature annotation may be derived. A database is 
 required for generating new data files with features. This option may 
 skipped when using coordinate information from an input file (e.g. BED 
 file), or when using an existing input file with the database indicated 
-in the metadata. For more information about using annotation databases, 
-see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
+in the metadata.  
 
 =item --feature <type | type:source | alias>,...
 
-=item --feature genome
-
 Specify the type of feature from which to collect values. This is required 
 only for new feature tables. Three types of values may be passed: the 
 feature type, feature type and source expressed as 'type:source', or an 
-alias to one or more feature types. Aliases are specified in the 
-C<biotoolbox.cfg> file and provide a shortcut to a list of one or more 
-database features. More than one feature may be included as a 
-comma-delimited list (no spaces). 
+alias to one or more feature types. More than one feature may be included 
+as a comma-delimited list (no spaces). 
+
+=back
+
+=head2 Options for feature "genome"
+
+=over 4
+
+=item --feature genome
 
 To collect genomic intervals (or regions) simply specify 'genome' as 
 the feature type.
 
-=item --win <integer>
+=item --win E<lt>integerE<gt>
 
 When generating a new genome interval list (feature type 'genome'), 
-optionally specify the window size. The default size is defined in the 
-configuration file, biotoolbox.cfg. 
+optionally specify the window size.  
 
-=item --step <integer>
+=item --step E<lt>integerE<gt>
 
 Optionally indicate the step size when generating a new list of intervals 
 across the genome. The default is equal to the window size.
 
-=item --ddb <name | filename>
+=back
+
+=head2 Options for data collection
+
+=over 4
+
+=item --ddb E<lt>nameE<gt>
 
 If the data to be collected is from a second database that is separate 
 from the annotation database, provide the name of the data database here. 
-Typically, a second C<Bio::DB::SeqFeature::Store> or BigWigSet database 
+Typically, a second L<Bio::DB::SeqFeature::Store> or BigWigSet database 
 is provided here. 
 
 =item --data <type1,type2,type3&type4,...>
@@ -974,11 +999,11 @@ merged into one by delimiting with an ampersand "&" (no spaces!). If no
 dataset is specified on the command line, then the program will 
 interactively present a list of datasets from the database to select. 
 
-The dataset may be a feature type in a BioPerl Bio::DB::SeqFeature::Store 
-or Bio::DB::BigWigSet database. Provide either the feature type or 
+The dataset may be a feature type in a BioPerl L<Bio::DB::SeqFeature::Store> 
+or L<Bio::DB::BigWigSet> database. Provide either the feature type or 
 type:source. The feature may point to another data file whose path is 
 stored in the feature's attribute tag (for example a binary 
-Bio::Graphics::Wiggle .wib file, a bigWig file, or Bam file), or the 
+Bio::Graphics::Wiggle F<.wib> file, a bigWig file, or Bam file), or the 
 features' scores may be used in data collection.
 
 Alternatively, the dataset may be a database file, including bigWig (.bw), 
@@ -988,7 +1013,7 @@ be local or remote (specified with a http: or ftp: prefix).
 To force the program to simply write out the list of collected features 
 without collecting data, provide the dataset name of "none".
 
-=item --method <text>
+=item --method E<lt>textE<gt>
 
 Specify the method for combining all of the dataset values within the 
 genomic region of the feature. Accepted values include:
@@ -1031,7 +1056,7 @@ Specify whether stranded data should be collected for each of the
 datasets. Either sense or antisense (relative to the feature) data 
 may be collected. Note that strand is not supported with some 
 data files, including bigWig files (unless specified through a GFF3 feature 
-attribute or Bio::DB::BigWigSet database) and Bam files (score coverage
+attribute or BigWigSet database) and Bam files (score coverage
 is not but count is). The default value is 'all', indicating all data 
 will be collected.  
 
@@ -1085,33 +1110,32 @@ tables or other Seq types, such as ChIPSeq. This option can only be used
 with one of the count methods (count, ncount, pcount). The FPKM values 
 are appended as additional columns in the output table.
 
-=item --extend <integer>
+=back
+
+=head2 Adjustments to features
+
+=over 4
+
+=item --extend E<lt>integerE<gt>
 
 Optionally specify the bp extension that will be added to both sides of the 
 feature's region.
 
-=item --start=<integer>
+=item --start E<lt>integerE<gt>
 
-=item --stop=<integer>
+=item --stop E<lt>integerE<gt>
+
+=item --begin E<lt>integerE<gt>
+
+=item --end E<lt>integerE<gt>
 
 Optionally specify adjustment values to adjust the region to collect values 
-relative to the feature position defined by the --pos option (default is 
+relative to the feature position defined by the C<--pos> option (default is 
 the 5' position). A negative value is shifted upstream (5' direction), 
 and a positive value is shifted downstream. Adjustments are always made 
 relative to the feature's strand. Both options must be applied; one is 
 not allowed.
 
-=item --fstart=<number>
-
-=item --fstop=<number>
-
-Optionally specify the fractional start and stop position of the region to 
-collect values as a function of the feature's length and relative to the 
-specified feature position defined by the --pos option (default is 5'). The 
-fraction should be presented as a decimal number, e.g. 0.25. Prefix a 
-negative sign to specify an upstream position. Both options must be 
-applied; one is not allowed. 
-
 =item --pos [5|m|3]
 
 Indicate the relative position of the feature with which the 
@@ -1121,23 +1145,40 @@ and "fstop" options. Three values are accepted: "5" indicates the
 indicates the middle of the feature is used. The default is to 
 use the 5' end, or the start position of unstranded features. 
 
-=item --limit <integer>
+=item --fstart=<number>
+
+=item --fstop=<number>
+
+Optionally specify the fractional start and stop position of the region to 
+collect values as a function of the feature's length and relative to the 
+specified feature position defined by the C<--pos> option (default is 5'). The 
+fraction should be presented as a decimal number, e.g. 0.25. Prefix a 
+negative sign to specify an upstream position. Both options must be 
+applied; one is not allowed. 
+
+=item --limit E<lt>integerE<gt>
 
 Optionally specify the minimum size limit for subfractionating a feature's 
 region. Used in combination with fstart and fstop to prevent taking a 
 subregion from a region too small to support it. The default is 10 bp.
 
+=back
+
+=head2 General options
+
+=over 4
+
 =item --gz
 
 Indicate whether the output file should (not) be compressed by gzip. 
-If compressed, the extension '.gz' is appended to the filename. If a compressed 
+If compressed, the extension F<.gz> is appended to the filename. If a compressed 
 file is opened, the compression status is preserved unless specified otherwise.
 
-=item --cpu <integer>
+=item --cpu E<lt>integerE<gt>
 
 Specify the number of CPU cores to execute in parallel. This requires 
-the installation of Parallel::ForkManager. With support enabled, the 
-default is 2. Disable multi-threaded execution by setting to 1. 
+the installation of L<Parallel::ForkManager>. With support enabled, the 
+default is 4. Disable multi-threaded execution by setting to 1. 
 
 =item --version
 
@@ -1153,7 +1194,7 @@ Display the POD documentation for this program.
 
 This program will collect dataset values from a variety of sources, including 
 features in a BioPerl Bio::DB::SeqFeature::Store database, binary wig files 
-(.wib) loaded in a database using Bio::Graphics::Wiggle, bigWig files, 
+F<.wib> loaded in a database using Bio::Graphics::Wiggle, bigWig files, 
 bigBed files, Bam alignment files, or a Bio::DB::BigWigSet database. 
 
 The values are collected for a list of known database features (genes, 
