@@ -4,7 +4,7 @@
 
 use strict;
 use warnings;
-use Getopt::Long;
+use Getopt::Long qw(:config no_ignore_case bundling);
 use Pod::Usage;
 use Bio::Range;
 use Bio::ToolBox::Data;
@@ -14,7 +14,7 @@ use Bio::ToolBox::db_helper qw(
 	get_chromosome_list
 );
 use Bio::ToolBox::utility;
-my $VERSION = 1.54;
+my $VERSION = 1.60;
 
 
 print "\n A script to pull out overlapping features\n\n";
@@ -47,18 +47,18 @@ my (
 );
 my @search_features;
 GetOptions( 
-	'in=s'       => \$infile, # the input nucleosome data file
-	'db=s'       => \$database, # the name of the database
-	'feature=s'  => \@search_features, # the feature(s) to look for
-	'start=i'    => \$start, # the relative start position
-	'stop=i'     => \$stop, # the relative stop position
-	'pos=s'      => \$adjustment_position, # the coordinate to make start and stop adjustments
-	'extend=i'   => \$extend, # extend lookup-feature by this amount
-	'ref=s'      => \$reference_position, # relative position when calc distance
-	'out=s'      => \$outfile, # output file name
-	'gz!'        => \$gz, # compress file
-	'help'       => \$help, # request help
-	'version'    => \$print_version, # print the version
+	'i|in=s'          => \$infile, # the input nucleosome data file
+	'd|db=s'          => \$database, # the name of the database
+	'f|feature=s'     => \@search_features, # the feature(s) to look for
+	'b|begin|start=i' => \$start, # the relative start position
+	'e|end|stop=i'    => \$stop, # the relative stop position
+	'p|pos=s'         => \$adjustment_position, # the coordinate to make start and stop adjustments
+	'x|extend=i'      => \$extend, # extend lookup-feature by this amount
+	'r|ref=s'         => \$reference_position, # relative position when calc distance
+	'o|out=s'         => \$outfile, # output file name
+	'z|gz!'           => \$gz, # compress file
+	'h|help'          => \$help, # request help
+	'v|version'       => \$print_version, # print the version
 ) or die " unrecognized option(s)!! please refer to the help documentation\n\n";
 
 # Print help
@@ -656,33 +656,41 @@ __END__
 
 get_intersecting_features.pl
 
-A script to pull out overlapping features from the database.
+A program to pull out overlapping features from the database.
 
 =head1 SYNOPSIS
 
 get_intersecting_features.pl [--options] <filename>
   
-  Options:
-  --in <filename>
-  --db <database>
-  --feature <text>
-  --start <integer>
-  --stop <integer>
-  --pos [5 | m | 3]
-  --extend <integer>
-  --ref [start | mid]
-  --out <filename>
-  --gz
-  --version
-  --help
+  File options:
+  -i --in <filename>                input file
+  -o --out <filename>               optionally output file
+  
+  Database options:
+  -d --db <database>                database to search: name or sqlite
+  -f --feature <text>               db feature to search
+  
+  Modify search range:
+  -b --begin --start <integer>      adjust relative search start coordinate
+  -e --end --stop <integer>         adjust relative search stop coordinate
+  -p --pos [5 | m | 3]              relative position of search coordinate
+  -x --extend <integer>             extend search in both directions
+  -r --ref [start | mid]            measure distance from which coordinate
+  
+  General options:
+  -z --gz                           compress output
+  -v --version                      print version and exit
+  -h --help                         show extended documentation
 
 =head1 OPTIONS
 
 The command line flags and descriptions:
 
+=head2 File options:
+
 =over 4
 
-=item --in <filename>
+=item --in E<lt>filenameE<gt>
 
 Specify an input file containing either a list of database features or 
 genomic coordinates for which to collect data. The file should be a 
@@ -692,17 +700,27 @@ first row should be column headers. Bed files are acceptable, as are
 text files generated by other B<BioToolBox> scripts. Files may be 
 gzipped compressed.
 
-=item --db <database>
+=item --out E<lt>filenameE<gt>
 
-Specify the name of a C<Bio::DB::SeqFeature::Store> annotation database 
+Optionally specify a new filename. A standard tim data text file is written. 
+The default is to rewrite the input file.
+
+=back
+
+=head2 Database options
+
+=over 4
+
+=item --db E<lt>databaseE<gt>
+
+Specify the name of a L<Bio::DB::SeqFeature::Store> annotation database 
 from which gene or feature annotation may be derived. A database is 
 required for generating new data files with features. This option may 
 skipped when using coordinate information from an input file (e.g. BED 
 file), or when using an existing input file with the database indicated 
-in the metadata. For more information about using annotation databases, 
-see L<https://code.google.com/p/biotoolbox/wiki/WorkingWithDatabases>. 
+in the metadata.  
 
-=item --feature <text>
+=item --feature E<lt>textE<gt>
 
 Specify the name of the target features to search for in the database that 
 intersect with the list of reference features. The type may be a either a 
@@ -710,9 +728,19 @@ GFF "type" or a "type:method" string. If not specifed, then the database
 will be queried for potential GFF types and a list presented to the user to 
 select one.
 
-=item --start <integer>
+=back
 
-=item --stop <integer>
+=head2 Modify search range
+
+=over 4
+
+=item --start E<lt>integerE<gt>
+
+=item --stop E<lt>integerE<gt>
+
+=item --begin E<lt>integerE<gt>
+
+=item --end E<lt>integerE<gt>
 
 Optionally specify the relative start and stop positions from the 5' end 
 (default) or the end specified by the "--pos" option with which to restrict 
@@ -727,7 +755,7 @@ search window. Both start and stop adjustments may be made from the
 respective 5 prime, 3 prime, or middle position as dictated by the feature's 
 strand value. 
 
-=item --extend <integer>
+=item --extend E<lt>integerE<gt>
 
 Optionally specify the number of bp to extend the reference feature's region 
 on each side. Useful when you have small reference regions and you want to 
@@ -740,10 +768,11 @@ reference and target features. The same reference point is used for both
 features. Valid options include "start" (or 5' end for stranded features) and 
 "mid" (for midpoint). Default is "start".
 
-=item --out <filename>
+=back
 
-Optionally specify a new filename. A standard tim data text file is written. 
-The default is to rewrite the input file.
+=head2 General options
+
+=over 4
 
 =item --gz
 
@@ -780,7 +809,7 @@ of the features, or optionally the midpoints. Note that the distance
 measurement is relative to the coordinates after adjustment with the --start, 
 --stop, and --extend options.
 
-A standard tim data text file is written.
+A standard BioToolBox data text file is written.
 
 =head1 AUTHOR
 
